# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: scribelog.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0fscribelog.proto\x12\x1e\x63om.vng.zlb.scribelog.grpc.lib"\x15\n\x04Ping\x12\r\n\x05\x63ount\x18\x01 \x01(\x03"\x15\n\x04Pong\x12\r\n\x05\x63ount\x18\x01 \x01(\x03"^\n\x12ListOfEntryRequest\x12H\n\x0flogEntryRequest\x18\x01 \x03(\x0b\x32/.com.vng.zlb.scribelog.grpc.lib.LogEntryRequest"d\n\x16ListOfActionLogRequest\x12J\n\x10\x61\x63tionLogRequest\x18\x01 \x03(\x0b\x32\x30.com.vng.zlb.scribelog.grpc.lib.ActionLogRequest"9\n\x10\x41\x63tionLogRequest\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12\x12\n\njson_param\x18\x02 \x01(\t"\x97\x01\n\x0fLogEntryRequest\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x10\n\x08\x61pp_name\x18\x03 \x01(\t\x12\x10\n\x08\x61pp_prop\x18\x04 \x01(\t\x12;\n\tlog_entry\x18\x05 \x01(\x0b\x32(.com.vng.zlb.scribelog.grpc.lib.LogEntry"6\n\x0eLogEntryResult\x12\r\n\x05\x65rror\x18\x01 \x01(\x05\x12\x15\n\rerror_message\x18\x02 \x01(\t"\x9e\x02\n\x08LogEntry\x12\n\n\x02ip\x18\x01 \x01(\t\x12\x0e\n\x06src_id\x18\x02 \x01(\x05\x12\x0e\n\x06\x64\x65s_id\x18\x03 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x04 \x01(\r\x12\x13\n\x0bsub_command\x18\x05 \x01(\r\x12\x0e\n\x06result\x18\x06 \x01(\x05\x12\x12\n\nstart_time\x18\x07 \x01(\x03\x12\x14\n\x0c\x65xecute_time\x18\x08 \x01(\x03\x12\x12\n\njson_param\x18\t \x01(\t\x12\x16\n\x0ejson_ext_param\x18\n \x01(\t\x12\x13\n\x0b\x63lient_type\x18\x0b \x01(\r\x12\x16\n\x0e\x63lient_version\x18\x0c \x01(\x05\x12\x0c\n\x04type\x18\r \x01(\r\x12\x0e\n\x06\x64p_log\x18\x0e \x01(\t\x12\x0f\n\x07\x64p_cate\x18\x0f \x01(\t2\xbd\x05\n\x10ScribeLogService\x12l\n\x07sendLog\x12/.com.vng.zlb.scribelog.grpc.lib.LogEntryRequest\x1a..com.vng.zlb.scribelog.grpc.lib.LogEntryResult"\x00\x12t\n\x0csendMultiLog\x12\x32.com.vng.zlb.scribelog.grpc.lib.ListOfEntryRequest\x1a..com.vng.zlb.scribelog.grpc.lib.LogEntryResult"\x00\x12s\n\rsendActionLog\x12\x30.com.vng.zlb.scribelog.grpc.lib.ActionLogRequest\x1a..com.vng.zlb.scribelog.grpc.lib.LogEntryResult"\x00\x12~\n\x12sendMultiActionLog\x12\x36.com.vng.zlb.scribelog.grpc.lib.ListOfActionLogRequest\x1a..com.vng.zlb.scribelog.grpc.lib.LogEntryResult"\x00\x12v\n\x0esendMultiLogV2\x12\x32.com.vng.zlb.scribelog.grpc.lib.ListOfEntryRequest\x1a..com.vng.zlb.scribelog.grpc.lib.LogEntryResult"\x00\x12X\n\x08pingPong\x12$.com.vng.zlb.scribelog.grpc.lib.Ping\x1a$.com.vng.zlb.scribelog.grpc.lib.Pong"\x00\x42\x32\n\x1e\x63om.vng.zlb.scribelog.grpc.libB\x0eScribeLogProtoP\x01\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "scribelog_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = (
        b"\n\036com.vng.zlb.scribelog.grpc.libB\016ScribeLogProtoP\001"
    )
    _globals["_PING"]._serialized_start = 51
    _globals["_PING"]._serialized_end = 72
    _globals["_PONG"]._serialized_start = 74
    _globals["_PONG"]._serialized_end = 95
    _globals["_LISTOFENTRYREQUEST"]._serialized_start = 97
    _globals["_LISTOFENTRYREQUEST"]._serialized_end = 191
    _globals["_LISTOFACTIONLOGREQUEST"]._serialized_start = 193
    _globals["_LISTOFACTIONLOGREQUEST"]._serialized_end = 293
    _globals["_ACTIONLOGREQUEST"]._serialized_start = 295
    _globals["_ACTIONLOGREQUEST"]._serialized_end = 352
    _globals["_LOGENTRYREQUEST"]._serialized_start = 355
    _globals["_LOGENTRYREQUEST"]._serialized_end = 506
    _globals["_LOGENTRYRESULT"]._serialized_start = 508
    _globals["_LOGENTRYRESULT"]._serialized_end = 562
    _globals["_LOGENTRY"]._serialized_start = 565
    _globals["_LOGENTRY"]._serialized_end = 851
    _globals["_SCRIBELOGSERVICE"]._serialized_start = 854
    _globals["_SCRIBELOGSERVICE"]._serialized_end = 1555
# @@protoc_insertion_point(module_scope)
